@@ -10,7 +10,7 @@ from sqlalchemy import (Column, Table, Integer, ForeignKey, Float,
 from sqlalchemy.engine import create_engine
 from sqlalchemy.orm import scoped_session, sessionmaker
 from xml.dom.minidom import parseString, parse
-from collections import Mapping
+from collections import Mapping, OrderedDict
 
 #TODO rewrite this to simple import
 from .utilities import (
@@ -35,7 +35,9 @@ ATTR_TYPES = {
     'cost_per_meter': ('cpm', 'int'),
     'pl': ('pl', 'int'),
     'type': ('t', 'unicode'),
-    'note': ('nt', 'unicode')
+    'note': ('nt', 'unicode'),
+    'available_total': ('at', 'int'),
+    'available_detail': ('ad', 'dict')
 }
 
 session = None
@@ -84,11 +86,38 @@ class FloorError(Exception):
 
 class Entity(object):
 
+    def fetch_apartments(self, available_only=False, room_count=0):
+        """Fetch apartments for the entity"""
+        return []
+
     @property
     def fs_name(self):
         """Return class name for use in filesystem (directories, etc.)"""
         return self.__class__.__name__.lower()
 
+    @property
+    def available_total(self):
+        """Return total number of available lots"""
+        total = len(self.fetch_apartments(available_only=True))
+        return total
+
+    @property
+    def available_detail(self):
+        """Return total number of available lots per room count"""
+        result = OrderedDict()
+        result['at'] = self.available_total
+        result['1'] = len(self.fetch_apartments(available_only=True,
+                                                room_count=1))
+        result['2'] = len(self.fetch_apartments(available_only=True,
+                                                room_count=2))
+        result['3'] = len(self.fetch_apartments(available_only=True,
+                                                room_count=3))
+        result['4'] = len(self.fetch_apartments(available_only=True,
+                                                room_count=4))
+        result['5'] = len(self.fetch_apartments(available_only=True,
+                                                room_count=5))
+        return result
+
     @classmethod
     def fetch(cls, key):
         return session.query(cls).get(key)
